changeset 743:5e745e03408a

Commit 729 broke canadian cross to fix ppc440 build, so try again to hopefully fix _both_ issues.
author Rob Landley <rob@landley.net>
date Thu, 11 Jun 2009 00:26:15 -0500
parents 46c4978c9a5c
children 759adf5a0fe9
files sources/include.sh
diffstat 1 files changed, 8 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/sources/include.sh	Sun May 31 02:36:22 2009 -0500
+++ b/sources/include.sh	Thu Jun 11 00:26:15 2009 -0500
@@ -95,17 +95,22 @@
   # during root-filesystem.sh, and the host compiler links binaries against the
   # wrong libc.)
   [ -z "$CROSS_HOST" ] && export CROSS_HOST=`uname -m`-walrus-linux
-  [ -z "$CROSS_TARGET" ] && export CROSS_TARGET=${ARCH}-unknown-linux
+  if [ -z "$CROSS_TARGET" ]
+  then
+    export CROSS_TARGET=${ARCH}-unknown-linux
+  else
+    [ -z "$FROM_HOST" ] && FROM_HOST="${CROSS_TARGET}"
+  fi
 
   # Override these to perform a canadian cross in root-filesystem.sh
 
   if [ -z "$FROM_ARCH" ]
   then
     FROM_ARCH="${ARCH}"
-    FROM_HOST="${CROSS_TARGET}"
   else
     [ -z "$PROGRAM_PREFIX" ] && PROGRAM_PREFIX="${ARCH}-"
   fi
+  [ -z "$FROM_HOST" ] && FROM_HOST="${FROM_ARCH}-thingy-linux"
 
   # Setup directories and add the cross compiler to the start of the path.
@@ -95,17 +95,22 @@
 
-  # Override these to perform a canadian cross in root-filesystem.sh
+  # Override FROM_ARCH to perform a canadian cross in root-filesystem.sh
 
   if [ -z "$FROM_ARCH" ]